@@ -1,4 +1,5 @@
 from mingus.containers.Note import Note
+from mingus.containers.NoteContainer import NoteContainer
 from random import randrange
 from mingus.containers.Track import Track
 from mingus.containers.Bar import Bar
@@ -13,6 +14,7 @@ class Instrument:
 	playing = []
 	last_played = []
 	last_chan= 0
+	last_bpm = 0
 
 	start = 0
 	end = -1
@@ -114,6 +116,11 @@ class Instrument:
 			for note in n:
 				note.velocity = v
 				note.channel = c
+			
+			#if self.last_bpm != state["bpm"]:
+			#	self.last_bpm = state["bpm"]
+			#	n = NoteContainer(n)
+			#	n.bpm = state["bpm"]
 
 			self.record_notes(state, n, dur)
 
