@@ -1,7 +1,7 @@
 import Movement
 
 class FluentMovement(Movement.Movement):
-	"""Preserves the bpm and wildness when switching blocks."""
+	"""Preserves the bpm and wildness between blocks."""
 	
 	last_bpm = 0
 	last_wildness = 0
