@@ -103,7 +103,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			self.remove_instrument)
 		self.connect(self.ui.clearinstruments,
 			QtCore.SIGNAL("clicked()"),
-			self.ui.instruments.clear)
+			lambda: self.ui.instruments.clear() or self.instrument_changed())
 		self.connect(self.ui.editblock,
 			QtCore.SIGNAL("clicked()"),
 			self.edit_block)
@@ -173,12 +173,13 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.copyprogression,
 			QtCore.SIGNAL("clicked()"),
 			self.copy_progression)
-		self.connect(self.ui.exportprogressions,
-			QtCore.SIGNAL("clicked()"),
-			self.export_progression)
-		self.connect(self.ui.importprogression,
-			QtCore.SIGNAL("clicked()"),
+		self.connect(self.ui.importprogressions,
+			QtCore.SIGNAL("activated()"),
 			self.import_progression)
+		self.connect(self.ui.exportprogressions,
+			QtCore.SIGNAL("activated()"),
+			self.export_progression)
+
 		self.connect(self.ui.movement,
 			QtCore.SIGNAL("highlighted(int)"),
 			self.highlighted_movement)
@@ -187,7 +188,15 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			self.connect(self.ui.uploadbutton,
 				QtCore.SIGNAL("clicked()"),
 				self.upload_song)
+			self.connect(self.ui.uploadsong,
+				QtCore.SIGNAL("activated()"),
+				self.upload_song)
+
 			self.ui.uploadbutton.setEnabled(True)
+			self.ui.menuUpload.setEnabled(True)
+		else:
+			self.ui.uploadbutton.setEnabled(False)
+			self.ui.menuUpload.setEnabled(False)
 		
 
 	def highlighted_movement(self, index):
@@ -239,6 +248,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 
 		self.set_title()
 		self.progression_changed()
+		self.instrument_changed()
 	
 	def add_block(self):
 		self.ui.blocks.addItem("Block")
@@ -296,6 +306,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			except Options.OptionError, err:
 				self.set_status("Error: " + str(err))
 		self.progression_changed()
+		self.ui.Tabs.setCurrentIndex(4)
 
 
 	def export_progression(self):
@@ -327,6 +338,12 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			self.enable_progression(False)
 		else:
 			self.enable_progression(True)
+
+	def instrument_changed(self):
+		if self.ui.instruments.count() == 0:
+			self.enable_instruments(False)
+		else:
+			self.enable_instruments(True)
 		
 
 	def enable_progression(self, enable = True):
@@ -342,20 +359,35 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			self.ui.upprogression.setEnabled(enable)
 			self.ui.downprogression.setEnabled(enable)
 
+	def enable_instruments(self, enable = True):
+		self.ui.upinstrument.setEnabled(False)
+		self.ui.downinstrument.setEnabled(False)
+		self.ui.clearinstruments.setEnabled(enable)
+		self.ui.copyinstrument.setEnabled(enable)
+		self.ui.editinstrument.setEnabled(enable)
+		self.ui.removeinstrument.setEnabled(enable)
+
+		if enable and self.ui.instruments.count() > 1:
+			self.ui.upinstrument.setEnabled(enable)
+			self.ui.downinstrument.setEnabled(enable)
+
 	def add_instrument(self):
 		self.ui.instruments.addItem(self.ui.instrumentcombo.currentText())
 		self.ui.instruments.setCurrentRow(int(self.ui.instruments.count()) -1)
 		self.edit_instrument()
+		self.instrument_changed()
 
 	def remove_instrument(self):
 		i = self.ui.instruments.currentRow()
 		if i >= 0:
 			self.ui.instruments.takeItem(i)
+		self.instrument_changed()
 
 	def copy_instrument(self):
 		i = self.ui.instruments.currentRow()
 		if i >= 0:
 			self.ui.instruments.addItem(self.ui.instruments.item(i).text())
+		self.instrument_changed()
 
 
 	def edit_block(self):
@@ -375,6 +407,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		i.load_instrument(str(cur.text()))
 		i.show()
 		i.exec_()
+		self.instrument_changed()
 
 	def edit_progression(self):
 		cur = self.ui.progressions.item(self.ui.progressions.currentRow())
@@ -526,6 +559,8 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 					self.ui.progressions.addItem(p)
 				except:
 					pass
+		self.progression_changed()
+		self.instrument_changed()
 
 	def get_options(self):
 		o = OptionClass()
