@@ -7,6 +7,10 @@ from sys import argv
 
 def show_main(params):
 	i = ImproviserMainWindow()
+	i.loggedin = params["login"]
+	i.credentials = {"username": params["username"], 
+			 "password": params["password"]}
+
 	if 'soundfont' not in params:
 		i.no_fluidsynth = True
 		i.soundfont = ''
@@ -15,6 +19,7 @@ def show_main(params):
 		i.no_fluidsynth = False
 		i.soundfont = params["soundfont"]
 		i.driver = params["driver"]
+	i.connect_widgets()
 	i.show()
 
 app = QtGui.QApplication(argv)
